@@ -5,7 +5,7 @@
 
 class AutoGain : public PluginBase {
  public:
-  AutoGain(const std::string& tag, const std::string& schema);
+  AutoGain(const std::string& tag, const std::string& schema, const std::string& schema_path);
   AutoGain(const AutoGain&) = delete;
   auto operator=(const AutoGain&) -> AutoGain& = delete;
   AutoGain(const AutoGain&&) = delete;
