@@ -1,13 +1,14 @@
 #ifndef CROSSFEED_UI_HPP
 #define CROSSFEED_UI_HPP
 
-#include <gtkmm/button.h>
-#include <gtkmm/grid.h>
 #include "plugin_ui_base.hpp"
 
 class CrossfeedUi : public Gtk::Grid, public PluginUiBase {
  public:
-  CrossfeedUi(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder, const std::string& settings_name);
+  CrossfeedUi(BaseObjectType* cobject,
+              const Glib::RefPtr<Gtk::Builder>& builder,
+              const std::string& schema,
+              const std::string& schema_path);
   CrossfeedUi(const CrossfeedUi&) = delete;
   auto operator=(const CrossfeedUi&) -> CrossfeedUi& = delete;
   CrossfeedUi(const CrossfeedUi&&) = delete;
