@@ -1,13 +1,14 @@
 #ifndef EXCITER_UI_HPP
 #define EXCITER_UI_HPP
 
-#include <gtkmm/grid.h>
-#include <gtkmm/togglebutton.h>
 #include "plugin_ui_base.hpp"
 
 class ExciterUi : public Gtk::Grid, public PluginUiBase {
  public:
-  ExciterUi(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder, const std::string& settings_name);
+  ExciterUi(BaseObjectType* cobject,
+            const Glib::RefPtr<Gtk::Builder>& builder,
+            const std::string& schema,
+            const std::string& schema_path);
   ExciterUi(const ExciterUi&) = delete;
   auto operator=(const ExciterUi&) -> ExciterUi& = delete;
   ExciterUi(const ExciterUi&&) = delete;
@@ -23,6 +24,7 @@ class ExciterUi : public Gtk::Grid, public PluginUiBase {
 
   Gtk::LevelBar* harmonics_levelbar = nullptr;
   Gtk::Label* harmonics_levelbar_label = nullptr;
+  Gtk::SpinButton* ceil_freq = nullptr;
   Gtk::ToggleButton *ceil_active = nullptr, *listen = nullptr;
 };
 
