@@ -5,7 +5,7 @@
 
 class Gate : public PluginBase {
  public:
-  Gate(const std::string& tag, const std::string& schema);
+  Gate(const std::string& tag, const std::string& schema, const std::string& schema_path);
   Gate(const Gate&) = delete;
   auto operator=(const Gate&) -> Gate& = delete;
   Gate(const Gate&&) = delete;
