@@ -1,13 +1,14 @@
 #ifndef GATE_UI_HPP
 #define GATE_UI_HPP
 
-#include <gtkmm/comboboxtext.h>
-#include <gtkmm/grid.h>
 #include "plugin_ui_base.hpp"
 
 class GateUi : public Gtk::Grid, public PluginUiBase {
  public:
-  GateUi(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder, const std::string& settings_name);
+  GateUi(BaseObjectType* cobject,
+         const Glib::RefPtr<Gtk::Builder>& builder,
+         const std::string& schema,
+         const std::string& schema_path);
   GateUi(const GateUi&) = delete;
   auto operator=(const GateUi&) -> GateUi& = delete;
   GateUi(const GateUi&&) = delete;
@@ -19,7 +20,7 @@ class GateUi : public Gtk::Grid, public PluginUiBase {
   void reset() override;
 
  private:
-  Glib::RefPtr<Gtk::Adjustment> attack, release, threshold, knee, ratio, range, makeup;
+  Glib::RefPtr<Gtk::Adjustment> attack, release, threshold, knee, ratio, range, input, makeup;
   Gtk::LevelBar* gating = nullptr;
   Gtk::Label* gating_label = nullptr;
   Gtk::ComboBoxText *detection = nullptr, *stereo_link = nullptr;
