@@ -11,7 +11,7 @@ class MaximizerPreset : public PluginPresetBase {
   void read(PresetType preset_type, const boost::property_tree::ptree& root) override;
 
  private:
-  Glib::RefPtr<Gio::Settings> output_settings;
+  Glib::RefPtr<Gio::Settings> output_settings, input_settings;
 
   void save(boost::property_tree::ptree& root,
             const std::string& section,
