@@ -1,15 +1,14 @@
 #ifndef MULTIBAND_GATE_UI_HPP
 #define MULTIBAND_GATE_UI_HPP
 
-#include <gtkmm/button.h>
-#include <gtkmm/comboboxtext.h>
-#include <gtkmm/grid.h>
-#include <gtkmm/togglebutton.h>
 #include "plugin_ui_base.hpp"
 
 class MultibandGateUi : public Gtk::Grid, public PluginUiBase {
  public:
-  MultibandGateUi(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder, const std::string& settings_name);
+  MultibandGateUi(BaseObjectType* cobject,
+                  const Glib::RefPtr<Gtk::Builder>& builder,
+                  const std::string& schema,
+                  const std::string& schema_path);
   MultibandGateUi(const MultibandGateUi&) = delete;
   auto operator=(const MultibandGateUi&) -> MultibandGateUi& = delete;
   MultibandGateUi(const MultibandGateUi&&) = delete;
