@@ -1,13 +1,14 @@
 #ifndef PITCH_UI_HPP
 #define PITCH_UI_HPP
 
-#include <gtkmm/grid.h>
-#include <gtkmm/togglebutton.h>
 #include "plugin_ui_base.hpp"
 
 class PitchUi : public Gtk::Grid, public PluginUiBase {
  public:
-  PitchUi(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder, const std::string& settings_name);
+  PitchUi(BaseObjectType* cobject,
+          const Glib::RefPtr<Gtk::Builder>& builder,
+          const std::string& schema,
+          const std::string& schema_path);
   PitchUi(const PitchUi&) = delete;
   auto operator=(const PitchUi&) -> PitchUi& = delete;
   PitchUi(const PitchUi&&) = delete;
