@@ -5,7 +5,7 @@
 
 class Reverb : public PluginBase {
  public:
-  Reverb(const std::string& tag, const std::string& schema);
+  Reverb(const std::string& tag, const std::string& schema, const std::string& schema_path);
   Reverb(const Reverb&) = delete;
   auto operator=(const Reverb&) -> Reverb& = delete;
   Reverb(const Reverb&&) = delete;
