@@ -1,14 +1,14 @@
 #ifndef REVERB_UI_HPP
 #define REVERB_UI_HPP
 
-#include <gtkmm/button.h>
-#include <gtkmm/comboboxtext.h>
-#include <gtkmm/grid.h>
 #include "plugin_ui_base.hpp"
 
 class ReverbUi : public Gtk::Grid, public PluginUiBase {
  public:
-  ReverbUi(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder, const std::string& settings_name);
+  ReverbUi(BaseObjectType* cobject,
+           const Glib::RefPtr<Gtk::Builder>& builder,
+           const std::string& schema,
+           const std::string& schema_path);
   ReverbUi(const ReverbUi&) = delete;
   auto operator=(const ReverbUi&) -> ReverbUi& = delete;
   ReverbUi(const ReverbUi&&) = delete;
