@@ -9,12 +9,10 @@
 #include "delay.hpp"
 #include "exciter.hpp"
 #include "loudness.hpp"
-#include "maximizer.hpp"
 #include "multiband_compressor.hpp"
 #include "multiband_gate.hpp"
 #include "pipeline_base.hpp"
 #include "pulse_manager.hpp"
-#include "stereo_tools.hpp"
 
 class SinkInputEffects : public PipelineBase {
  public:
@@ -28,11 +26,9 @@ class SinkInputEffects : public PipelineBase {
   std::unique_ptr<BassEnhancer> bass_enhancer;
   std::unique_ptr<Exciter> exciter;
   std::unique_ptr<Crossfeed> crossfeed;
-  std::unique_ptr<Maximizer> maximizer;
   std::unique_ptr<MultibandCompressor> multiband_compressor;
   std::unique_ptr<Loudness> loudness;
   std::unique_ptr<MultibandGate> multiband_gate;
-  std::unique_ptr<StereoTools> stereo_tools;
   std::unique_ptr<Convolver> convolver;
   std::unique_ptr<Crystalizer> crystalizer;
   std::unique_ptr<AutoGain> autogain;
@@ -44,8 +40,6 @@ class SinkInputEffects : public PipelineBase {
   sigc::signal<void, std::array<double, 2>> exciter_output_level;
   sigc::signal<void, std::array<double, 2>> crossfeed_input_level;
   sigc::signal<void, std::array<double, 2>> crossfeed_output_level;
-  sigc::signal<void, std::array<double, 2>> maximizer_input_level;
-  sigc::signal<void, std::array<double, 2>> maximizer_output_level;
   sigc::signal<void, std::array<double, 2>> loudness_input_level;
   sigc::signal<void, std::array<double, 2>> loudness_output_level;
   sigc::signal<void, std::array<double, 2>> convolver_input_level;
