@@ -7,12 +7,11 @@ class StereoToolsPreset : public PluginPresetBase {
  public:
   StereoToolsPreset();
 
-  void write(PresetType preset_type,
-             boost::property_tree::ptree& root) override;
+  void write(PresetType preset_type, boost::property_tree::ptree& root) override;
   void read(PresetType preset_type, const boost::property_tree::ptree& root) override;
 
  private:
-  Glib::RefPtr<Gio::Settings> output_settings;
+  Glib::RefPtr<Gio::Settings> output_settings, input_settings;
 
   void save(boost::property_tree::ptree& root,
             const std::string& section,
