@@ -1,14 +1,14 @@
 #ifndef WEBRTC_UI_HPP
 #define WEBRTC_UI_HPP
 
-#include <gtkmm/comboboxtext.h>
-#include <gtkmm/grid.h>
-#include <gtkmm/togglebutton.h>
 #include "plugin_ui_base.hpp"
 
 class WebrtcUi : public Gtk::Grid, public PluginUiBase {
  public:
-  WebrtcUi(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder, const std::string& settings_name);
+  WebrtcUi(BaseObjectType* cobject,
+           const Glib::RefPtr<Gtk::Builder>& builder,
+           const std::string& schema,
+           const std::string& schema_path);
   WebrtcUi(const WebrtcUi&) = delete;
   auto operator=(const WebrtcUi&) -> WebrtcUi& = delete;
   WebrtcUi(const WebrtcUi&&) = delete;
