@@ -1,8 +1,10 @@
 #include "compressor_preset.hpp"
 
 CompressorPreset::CompressorPreset()
-    : input_settings(Gio::Settings::create("com.github.wwmm.pulseeffects.sourceoutputs.compressor")),
-      output_settings(Gio::Settings::create("com.github.wwmm.pulseeffects.sinkinputs.compressor")) {}
+    : input_settings(Gio::Settings::create("com.github.wwmm.pulseeffects.compressor",
+                                           "/com/github/wwmm/pulseeffects/sourceoutputs/compressor/")),
+      output_settings(Gio::Settings::create("com.github.wwmm.pulseeffects.compressor",
+                                            "/com/github/wwmm/pulseeffects/sinkinputs/compressor/")) {}
 
 void CompressorPreset::save(boost::property_tree::ptree& root,
                             const std::string& section,
@@ -19,6 +21,8 @@ void CompressorPreset::save(boost::property_tree::ptree& root,
 
   root.put(section + ".compressor.release", settings->get_double("release"));
 
+  root.put(section + ".compressor.release-threshold", settings->get_double("release-threshold"));
+
   root.put(section + ".compressor.threshold", settings->get_double("threshold"));
 
   root.put(section + ".compressor.ratio", settings->get_double("ratio"));
@@ -27,6 +31,8 @@ void CompressorPreset::save(boost::property_tree::ptree& root,
 
   root.put(section + ".compressor.makeup", settings->get_double("makeup"));
 
+  root.put(section + ".compressor.boost-threshold", settings->get_double("boost-threshold"));
+
   root.put(section + ".compressor.sidechain.listen", settings->get_boolean("sidechain-listen"));
 
   root.put(section + ".compressor.sidechain.type", settings->get_string("sidechain-type"));
@@ -40,6 +46,14 @@ void CompressorPreset::save(boost::property_tree::ptree& root,
   root.put(section + ".compressor.sidechain.reactivity", settings->get_double("sidechain-reactivity"));
 
   root.put(section + ".compressor.sidechain.lookahead", settings->get_double("sidechain-lookahead"));
+
+  root.put(section + ".compressor.hpf-mode", settings->get_string("hpf-mode"));
+
+  root.put(section + ".compressor.hpf-frequency", settings->get_double("hpf-frequency"));
+
+  root.put(section + ".compressor.lpf-mode", settings->get_string("lpf-mode"));
+
+  root.put(section + ".compressor.lpf-frequency", settings->get_double("lpf-frequency"));
 }
 
 void CompressorPreset::load(const boost::property_tree::ptree& root,
@@ -57,6 +71,8 @@ void CompressorPreset::load(const boost::property_tree::ptree& root,
 
   update_key<double>(root, settings, "release", section + ".compressor.release");
 
+  update_key<double>(root, settings, "release-threshold", section + ".compressor.release-threshold");
+
   update_key<double>(root, settings, "threshold", section + ".compressor.threshold");
 
   update_key<double>(root, settings, "ratio", section + ".compressor.ratio");
@@ -65,6 +81,8 @@ void CompressorPreset::load(const boost::property_tree::ptree& root,
 
   update_key<double>(root, settings, "makeup", section + ".compressor.makeup");
 
+  update_key<double>(root, settings, "boost-threshold", section + ".compressor.boost-threshold");
+
   update_key<bool>(root, settings, "sidechain-listen", section + ".compressor.sidechain.listen");
 
   update_string_key(root, settings, "sidechain-type", section + ".compressor.sidechain.type");
@@ -78,6 +96,14 @@ void CompressorPreset::load(const boost::property_tree::ptree& root,
   update_key<double>(root, settings, "sidechain-reactivity", section + ".compressor.sidechain.reactivity");
 
   update_key<double>(root, settings, "sidechain-lookahead", section + ".compressor.sidechain.lookahead");
+
+  update_string_key(root, settings, "hpf-mode", section + ".compressor.hpf-mode");
+
+  update_key<double>(root, settings, "hpf-frequency", section + ".compressor.hpf-frequency");
+
+  update_string_key(root, settings, "lpf-mode", section + ".compressor.lpf-mode");
+
+  update_key<double>(root, settings, "lpf-frequency", section + ".compressor.lpf-frequency");
 }
 
 void CompressorPreset::write(PresetType preset_type, boost::property_tree::ptree& root) {
