@@ -2,15 +2,19 @@
 #include <glibmm.h>
 #include <glibmm/i18n.h>
 #include <gst/fft/gstfftf32.h>
+#include <gtkmm/filechoosernative.h>
 #include <boost/math/interpolators/cardinal_cubic_b_spline.hpp>
 #include <sndfile.hh>
+#include "gtkmm/dialog.h"
+// #include "gtkmm/window.h"
 #include "sigc++/functors/ptr_fun.h"
 
 ConvolverUi::ConvolverUi(BaseObjectType* cobject,
                          const Glib::RefPtr<Gtk::Builder>& builder,
-                         const std::string& settings_name)
+                         const std::string& schema,
+                         const std::string& schema_path)
     : Gtk::Grid(cobject),
-      PluginUiBase(builder, settings_name),
+      PluginUiBase(builder, schema, schema_path),
       irs_dir(Glib::get_user_config_dir() + "/PulseEffects/irs"),
       spectrum_settings(Gio::Settings::create("com.github.wwmm.pulseeffects.spectrum")) {
   name = "convolver";
@@ -220,7 +224,7 @@ auto ConvolverUi::on_listbox_sort(Gtk::ListBoxRow* row1, Gtk::ListBoxRow* row2)
 void ConvolverUi::populate_irs_listbox() {
   auto children = irs_listbox->get_children();
 
-  for (auto c : children) {
+  for (const auto& c : children) {
     irs_listbox->remove(*c);
   }
 
@@ -229,10 +233,10 @@ void ConvolverUi::populate_irs_listbox() {
   for (const auto& name : names) {
     auto b = Gtk::Builder::create_from_resource("/com/github/wwmm/pulseeffects/ui/irs_row.glade");
 
-    Gtk::ListBoxRow* row;
-    Gtk::Button* remove_btn;
-    Gtk::Button* apply_btn;
-    Gtk::Label* label;
+    Gtk::ListBoxRow* row = nullptr;
+    Gtk::Button* remove_btn = nullptr;
+    Gtk::Button* apply_btn = nullptr;
+    Gtk::Label* label = nullptr;
 
     b->get_widget("irs_row", row);
     b->get_widget("remove", remove_btn);
@@ -269,44 +273,35 @@ void ConvolverUi::on_irs_menu_button_clicked() {
 }
 
 void ConvolverUi::on_import_irs_clicked() {
-  // gtkmm 3.22 does not have FileChooseNative so we have to use C api :-(
+  auto* main_window = dynamic_cast<Gtk::Window*>(this->get_toplevel());
 
-  gint res;
+  auto dialog = Gtk::FileChooserNative::create(
+      _("Import Impulse File"), *main_window, Gtk::FileChooserAction::FILE_CHOOSER_ACTION_OPEN, _("Open"), _("Cancel"));
 
-  auto dialog = gtk_file_chooser_native_new(_("Import Impulse File"), (GtkWindow*)this->get_toplevel()->gobj(),
-                                            GTK_FILE_CHOOSER_ACTION_OPEN, _("Open"), _("Cancel"));
+  auto dialog_filter = Gtk::FileFilter::create();
 
-  auto filter = gtk_file_filter_new();
+  dialog_filter->set_name(_("Impulse Response"));
+  dialog_filter->add_pattern("*.irs");
+  dialog_filter->add_pattern("*.wav");
 
-  gtk_file_filter_set_name(filter, _("Impulse Response"));
-  gtk_file_filter_add_pattern(filter, "*.irs");
-  gtk_file_filter_add_pattern(filter, "*.wav");
-  gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(dialog), filter);
+  dialog->add_filter(dialog_filter);
 
-  res = gtk_native_dialog_run(GTK_NATIVE_DIALOG(dialog));
+  dialog->signal_response().connect([=](auto response_id) {
+    switch (response_id) {
+      case Gtk::ResponseType::RESPONSE_ACCEPT: {
+        import_irs_file(dialog->get_file()->get_path());
 
-  if (res == GTK_RESPONSE_ACCEPT) {
-    GtkFileChooser* chooser = GTK_FILE_CHOOSER(dialog);
+        populate_irs_listbox();
 
-    auto file_list = gtk_file_chooser_get_filenames(chooser);
+        break;
+      }
+      default:
+        break;
+    }
+  });
 
-    g_slist_foreach(
-        file_list,
-        [](auto data, auto user_data) {
-          auto cui = static_cast<ConvolverUi*>(user_data);
-
-          auto file_path = static_cast<char*>(data);
-
-          cui->import_irs_file(file_path);
-        },
-        this);
-
-    g_slist_free(file_list);
-  }
-
-  g_object_unref(dialog);
-
-  populate_irs_listbox();
+  dialog->set_modal(true);
+  dialog->show();
 }
 
 void ConvolverUi::get_irs_info() {
@@ -359,10 +354,14 @@ void ConvolverUi::get_irs_info() {
   right_mag.resize(frames_in);
 
   // ensure that the fft can be computed
-  if (left_mag.size() % 2 != 0)
+
+  if (left_mag.size() % 2 != 0) {
     left_mag.emplace_back(0);
-  if (right_mag.size() % 2 != 0)
+  }
+
+  if (right_mag.size() % 2 != 0) {
     right_mag.emplace_back(0);
+  }
 
   left_mag.shrink_to_fit();
   right_mag.shrink_to_fit();
@@ -459,8 +458,8 @@ void ConvolverUi::get_irs_spectrum(const int& rate) {
   right_spectrum.resize(nfft / 2 + 1);
 
   for (int i = 0; i < nfft / 2 + 1; i++) {
-    float v_l;
-    float v_r;
+    float v_l = 0.0;
+    float v_r = 0.0;
 
     // left
     v_l = freqdata_l[i].r * freqdata_l[i].r;
@@ -480,7 +479,7 @@ void ConvolverUi::get_irs_spectrum(const int& rate) {
   uint max_points = std::min((uint)left_spectrum.size(), max_plot_points);
 
   fft_min_freq = 1;
-  fft_max_freq = 0.5f * static_cast<float>(rate);
+  fft_max_freq = 0.5F * static_cast<float>(rate);
 
   freq_axis = util::logspace(log10(fft_min_freq), log10(fft_max_freq), max_points);
 
@@ -584,8 +583,8 @@ void ConvolverUi::draw_channel(Gtk::DrawingArea* da,
       msg.precision(3);
       msg << std::fixed << mouse_intensity;
 
-      int text_width;
-      int text_height;
+      int text_width = 0;
+      int text_height = 0;
       auto layout = create_pango_layout(msg.str());
       layout->set_font_description(font);
       layout->get_pixel_size(text_width, text_height);
@@ -606,9 +605,10 @@ void ConvolverUi::update_mouse_info_L(GdkEventMotion* event) {
   if (show_fft_spectrum) {
     float fft_min_freq_log = log10(fft_min_freq);
     float fft_max_freq_log = log10(fft_max_freq);
-    float mouse_freq_log = static_cast<float>(event->x) / width * (fft_max_freq_log - fft_min_freq_log) + fft_min_freq_log;
+    float mouse_freq_log =
+        static_cast<float>(event->x) / width * (fft_max_freq_log - fft_min_freq_log) + fft_min_freq_log;
 
-    mouse_freq = exp10(mouse_freq_log);
+    mouse_freq = std::pow(10.0F, mouse_freq_log);  // exp10 does not exist on FreeBSD
 
     mouse_intensity = (height - static_cast<float>(event->y)) / height * (fft_max_left - fft_min_left) + fft_min_left;
   } else {
@@ -627,11 +627,13 @@ void ConvolverUi::update_mouse_info_R(GdkEventMotion* event) {
   if (show_fft_spectrum) {
     float fft_min_freq_log = log10(fft_min_freq);
     float fft_max_freq_log = log10(fft_max_freq);
-    float mouse_freq_log = static_cast<float>(event->x) / width * (fft_max_freq_log - fft_min_freq_log) + fft_min_freq_log;
+    float mouse_freq_log =
+        static_cast<float>(event->x) / width * (fft_max_freq_log - fft_min_freq_log) + fft_min_freq_log;
 
-    mouse_freq = exp10(mouse_freq_log);
+    mouse_freq = std::pow(10.0F, mouse_freq_log);  // exp10 does not exist on FreeBSD
 
-    mouse_intensity = (height - static_cast<float>(event->y)) / height * (fft_max_right - fft_min_right) + fft_min_right;
+    mouse_intensity =
+        (height - static_cast<float>(event->y)) / height * (fft_max_right - fft_min_right) + fft_min_right;
   } else {
     mouse_time = static_cast<float>(event->x) * max_time / width;
 
