@@ -1,11 +1,14 @@
 #include "equalizer_ui.hpp"
 #include <glibmm/i18n.h>
-#include <gtkmm/label.h>
-#include <gtkmm/scale.h>
-#include <gtkmm/togglebutton.h>
+#include <gtkmm/filechoosernative.h>
+#include <boost/filesystem.hpp>
 #include <boost/property_tree/json_parser.hpp>
 #include <boost/property_tree/ptree.hpp>
+#include <cstddef>
 #include <cstring>
+#include <regex>
+#include "gtkmm/dialog.h"
+#include "gtkmm/window.h"
 
 namespace {
 
@@ -186,12 +189,14 @@ auto int_to_bandslope_enum(const GValue* value, const GVariantType* expected_typ
 EqualizerUi::EqualizerUi(BaseObjectType* cobject,
                          const Glib::RefPtr<Gtk::Builder>& builder,
                          const std::string& schema,
-                         const std::string& schema_left,
-                         const std::string& schema_right)
+                         const std::string& schema_path,
+                         const std::string& schema_channel,
+                         const std::string& schema_channel_left_path,
+                         const std::string& schema_channel_right_path)
     : Gtk::Grid(cobject),
-      PluginUiBase(builder, schema),
-      settings_left(Gio::Settings::create(schema_left)),
-      settings_right(Gio::Settings::create(schema_right)) {
+      PluginUiBase(builder, schema, schema_path),
+      settings_left(Gio::Settings::create(schema_channel, schema_channel_left_path)),
+      settings_right(Gio::Settings::create(schema_channel, schema_channel_right_path)) {
   name = "equalizer";
 
   // loading glade widgets
@@ -199,6 +204,7 @@ EqualizerUi::EqualizerUi(BaseObjectType* cobject,
   builder->get_widget("bands_grid_left", bands_grid_left);
   builder->get_widget("bands_grid_right", bands_grid_right);
   builder->get_widget("flat_response", flat_response);
+  builder->get_widget("import_apo", import_apo);
   builder->get_widget("calculate_freqs", calculate_freqs);
   builder->get_widget("presets_listbox", presets_listbox);
   builder->get_widget("split_channels", split_channels);
@@ -224,8 +230,10 @@ EqualizerUi::EqualizerUi(BaseObjectType* cobject,
 
   presets_listbox->set_sort_func(sigc::ptr_fun(&EqualizerUi::on_listbox_sort));
 
+  import_apo->signal_clicked().connect(sigc::mem_fun(*this, &EqualizerUi::on_import_apo_preset_clicked));
+
   connections.emplace_back(settings->signal_changed("split-channels").connect([&](auto key) {
-    for (auto c : connections_bands) {
+    for (auto& c : connections_bands) {
       c.disconnect();
     }
 
@@ -262,7 +270,7 @@ EqualizerUi::EqualizerUi(BaseObjectType* cobject,
 }
 
 EqualizerUi::~EqualizerUi() {
-  for (auto c : connections_bands) {
+  for (auto& c : connections_bands) {
     c.disconnect();
   }
 
@@ -270,7 +278,7 @@ EqualizerUi::~EqualizerUi() {
 }
 
 void EqualizerUi::on_nbands_changed() {
-  for (auto c : connections_bands) {
+  for (auto& c : connections_bands) {
     c.disconnect();
   }
 
@@ -287,7 +295,7 @@ void EqualizerUi::on_nbands_changed() {
 }
 
 void EqualizerUi::build_bands(Gtk::Grid* bands_grid, const Glib::RefPtr<Gio::Settings>& cfg, const int& nbands) {
-  for (auto* c : bands_grid->get_children()) {
+  for (const auto& c : bands_grid->get_children()) {
     bands_grid->remove(*c);
 
     delete c;
@@ -329,7 +337,7 @@ void EqualizerUi::build_bands(Gtk::Grid* bands_grid, const Glib::RefPtr<Gio::Set
     auto update_w = [=]() {
       auto q = band_quality->get_value();
 
-      if (q > 0) {
+      if (q > 0.0) {
         auto f = band_frequency->get_value();
 
         std::ostringstream msg;
@@ -348,7 +356,7 @@ void EqualizerUi::build_bands(Gtk::Grid* bands_grid, const Glib::RefPtr<Gio::Set
 
       std::ostringstream msg;
 
-      if (f > 1000) {
+      if (f > 1000.0) {
         msg.precision(1);
         msg << std::fixed << f / 1000 << "kHz";
       } else {
@@ -405,13 +413,13 @@ void EqualizerUi::build_bands(Gtk::Grid* bands_grid, const Glib::RefPtr<Gio::Set
 }
 
 void EqualizerUi::build_unified_bands(const int& nbands) {
-  for (auto c : bands_grid_left->get_children()) {
+  for (const auto& c : bands_grid_left->get_children()) {
     bands_grid_left->remove(*c);
 
     delete c;
   }
 
-  for (auto* c : bands_grid_right->get_children()) {
+  for (const auto& c : bands_grid_right->get_children()) {
     bands_grid_right->remove(*c);
 
     delete c;
@@ -453,7 +461,7 @@ void EqualizerUi::build_unified_bands(const int& nbands) {
     auto update_w = [=]() {
       auto q = band_quality->get_value();
 
-      if (q > 0) {
+      if (q > 0.0) {
         auto f = band_frequency->get_value();
 
         std::ostringstream msg;
@@ -472,7 +480,7 @@ void EqualizerUi::build_unified_bands(const int& nbands) {
 
       std::ostringstream msg;
 
-      if (f > 1000) {
+      if (f > 1000.0) {
         msg.precision(1);
         msg << std::fixed << f / 1000 << "kHz";
       } else {
@@ -574,7 +582,7 @@ void EqualizerUi::build_unified_bands(const int& nbands) {
 }
 
 void EqualizerUi::on_flat_response() {
-  for (int n = 0; n < 30; n++) {
+  for (int n = 0; n < max_bands; n++) {
     // left channel
 
     settings_left->reset(std::string("band" + std::to_string(n) + "-gain"));
@@ -650,7 +658,7 @@ void EqualizerUi::load_preset(const std::string& file_name) {
   settings->set_double("output-gain", root.get<double>("equalizer.output-gain"));
 
   auto config_band = [&](auto cfg, auto n) {
-    double q = 0;
+    double q = 0.0;
 
     auto f = root.get<double>("equalizer.band" + std::to_string(n) + ".frequency");
 
@@ -716,7 +724,7 @@ auto EqualizerUi::on_listbox_sort(Gtk::ListBoxRow* row1, Gtk::ListBoxRow* row2)
 void EqualizerUi::populate_presets_listbox() {
   auto children = presets_listbox->get_children();
 
-  for (auto* c : children) {
+  for (const auto& c : children) {
     presets_listbox->remove(*c);
   }
 
@@ -755,7 +763,7 @@ void EqualizerUi::reset() {
     settings->reset("input-gain");
     settings->reset("output-gain");
 
-    for (int n = 0; n < 30; n++) {
+    for (int n = 0; n < max_bands; n++) {
       // left channel
 
       settings_left->reset(std::string("band" + std::to_string(n) + "-gain"));
@@ -784,3 +792,159 @@ void EqualizerUi::reset() {
     util::debug(name + " plugin: an error occurred during reset process");
   }
 }
+
+void EqualizerUi::on_import_apo_preset_clicked() {
+  auto* main_window = dynamic_cast<Gtk::Window*>(this->get_toplevel());
+
+  auto dialog =
+      Gtk::FileChooserNative::create(_("Import APO Preset File"), *main_window,
+                                     Gtk::FileChooserAction::FILE_CHOOSER_ACTION_OPEN, _("Open"), _("Cancel"));
+
+  auto dialog_filter = Gtk::FileFilter::create();
+
+  dialog_filter->set_name(_("APO Presets"));
+  dialog_filter->add_pattern("*.txt");
+
+  dialog->add_filter(dialog_filter);
+
+  dialog->signal_response().connect([=](auto response_id) {
+    switch (response_id) {
+      case Gtk::ResponseType::RESPONSE_ACCEPT: {
+        import_apo_preset(dialog->get_file()->get_path());
+
+        break;
+      }
+      default:
+        break;
+    }
+  });
+
+  dialog->set_modal(true);
+  dialog->show();
+}
+
+// returns false if we cannot parse given line successfully
+auto EqualizerUi::parse_apo_filter(const std::string& line, struct ImportedBand& filter) -> bool {
+  std::smatch matches;
+  std::regex re_filter_type(R"(Filter[\s]+[\d]*:[\s]*ON[\s]+([\w]+))");
+  std::regex re_freq(R"([\s]+Fc[\s]*([\d]*[.]?[\d]*)[\s]*Hz)");
+  std::regex re_dB_per_octave(R"(Filter[\s]+[\d]*:[\s]*ON[\s]+[\w]+[\s]+([+-]?[\d]*[.]?[\d]*)[\s]*dB)");
+  std::regex re_gain(R"(Gain[\s]*([+-]?[\d]*[.]?[\d]*)[\s]*dB)");
+  std::regex re_quality_factor(R"([\s]+Q[\s]+([\d]*[.]?[\d]*))");
+
+  // get filter type
+  std::regex_search(line, matches, re_filter_type);
+
+  if (matches.size() != 2) {
+    return false;
+  }
+
+  try {
+    filter.type = EqualizerUi::FilterTypeMap.at(matches.str(1));
+  } catch (...) {
+    return false;
+  }
+
+  // get center frequency
+  std::regex_search(line, matches, re_freq);
+
+  if (matches.size() != 2) {
+    return false;
+  }
+
+  filter.freq = std::stof(matches.str(1));
+
+  // get slope
+
+  if ((filter.type & (LOW_SHELF_xdB | HIGH_SHELF_xdB | LOW_SHELF | HIGH_SHELF)) != 0U) {
+    std::regex_search(line, matches, re_dB_per_octave);
+    // _xdB variants require the dB parameter
+    if (((filter.type & (LOW_SHELF_xdB | HIGH_SHELF_xdB)) != 0U) && (matches.size() != 2)) {
+      return false;
+    }
+
+    if (matches.size() == 2) {
+      // we satisfied the condition, now assign the paramater if given
+      filter.slope_dB = std::stof(matches.str(1));
+    }
+  }
+
+  // get gain
+
+  if ((filter.type & (PEAKING | LOW_SHELF_xdB | HIGH_SHELF_xdB | LOW_SHELF | HIGH_SHELF)) != 0U) {
+    std::regex_search(line, matches, re_gain);
+    // all Shelf types (i.e. all above except for Peaking) require the gain parameter
+    if (((filter.type & PEAKING) == 0U) && (matches.size() != 2)) {
+      return false;
+    }
+
+    if (matches.size() == 2) {
+      filter.gain = std::stof(matches.str(1));
+    }
+  }
+
+  // get quality factor
+  if ((filter.type & (PEAKING | LOW_PASS_Q | HIGH_PASS_Q | LOW_SHELF_xdB | HIGH_SHELF_xdB | NOTCH | ALL_PASS)) != 0U) {
+    std::regex_search(line, matches, re_quality_factor);
+    // Peaking and All-Pass filter types require the quality factor parameter
+    if (((filter.type & (PEAKING | ALL_PASS)) != 0U) && (matches.size() != 2)) {
+      return false;
+    }
+
+    if (matches.size() == 2) {
+      filter.quality_factor = std::stof(matches.str(1));
+    }
+  }
+
+  return true;
+}
+
+void EqualizerUi::import_apo_preset(const std::string& file_path) {
+  boost::filesystem::path p{file_path};
+
+  if (boost::filesystem::is_regular_file(p)) {
+    std::ifstream eq_file;
+    std::vector<struct ImportedBand> bands;
+
+    eq_file.open(p.string());
+
+    if (eq_file.is_open()) {
+      std::string line;
+
+      while (getline(eq_file, line)) {
+        struct ImportedBand filter {};
+        bool parsed = this->parse_apo_filter(line, filter);
+
+        if (parsed) {
+          bands.push_back(filter);
+        }
+      }
+    }
+
+    eq_file.close();
+
+    if (bands.empty()) {
+      return;
+    }
+
+    settings->set_int("num-bands", bands.size());
+
+    for (int n = 0; n < max_bands; n++) {
+      if (n < static_cast<int>(bands.size())) {
+        settings_left->set_string(std::string("band" + std::to_string(n) + "-type"), "Bell");
+        settings_left->set_double(std::string("band" + std::to_string(n) + "-gain"), bands[n].gain);
+        settings_left->set_double(std::string("band" + std::to_string(n) + "-frequency"), bands[n].freq);
+        settings_left->set_double(std::string("band" + std::to_string(n) + "-q"), bands[n].quality_factor);
+
+        settings_right->set_string(std::string("band" + std::to_string(n) + "-type"), "Bell");
+        settings_right->set_double(std::string("band" + std::to_string(n) + "-gain"), bands[n].gain);
+        settings_right->set_double(std::string("band" + std::to_string(n) + "-frequency"), bands[n].freq);
+        settings_right->set_double(std::string("band" + std::to_string(n) + "-q"), bands[n].quality_factor);
+      } else {
+        settings_left->set_string(std::string("band" + std::to_string(n) + "-type"), "Off");
+
+        settings_right->set_string(std::string("band" + std::to_string(n) + "-type"), "Off");
+      }
+    }
+  }
+}
