@@ -11,7 +11,7 @@ void on_post_messages_changed(GSettings* settings, gchar* key, Exciter* l) {
     if (!l->harmonics_connection.connected()) {
       l->harmonics_connection = Glib::signal_timeout().connect(
           [l]() {
-            float harmonics;
+            float harmonics = 0.0;
 
             g_object_get(l->exciter, "meter-drive", &harmonics, nullptr);
 
@@ -28,20 +28,21 @@ void on_post_messages_changed(GSettings* settings, gchar* key, Exciter* l) {
 
 }  // namespace
 
-Exciter::Exciter(const std::string& tag, const std::string& schema) : PluginBase(tag, "exciter", schema) {
+Exciter::Exciter(const std::string& tag, const std::string& schema, const std::string& schema_path)
+    : PluginBase(tag, "exciter", schema, schema_path) {
   exciter = gst_element_factory_make("calf-sourceforge-net-plugins-Exciter", nullptr);
 
   if (is_installed(exciter)) {
-    auto in_level = gst_element_factory_make("level", "exciter_input_level");
-    auto out_level = gst_element_factory_make("level", "exciter_output_level");
-    auto audioconvert_in = gst_element_factory_make("audioconvert", "exciter_audioconvert_in");
-    auto audioconvert_out = gst_element_factory_make("audioconvert", "exciter_audioconvert_out");
+    auto* in_level = gst_element_factory_make("level", "exciter_input_level");
+    auto* out_level = gst_element_factory_make("level", "exciter_output_level");
+    auto* audioconvert_in = gst_element_factory_make("audioconvert", "exciter_audioconvert_in");
+    auto* audioconvert_out = gst_element_factory_make("audioconvert", "exciter_audioconvert_out");
 
     gst_bin_add_many(GST_BIN(bin), in_level, audioconvert_in, exciter, audioconvert_out, out_level, nullptr);
     gst_element_link_many(in_level, audioconvert_in, exciter, audioconvert_out, out_level, nullptr);
 
-    auto pad_sink = gst_element_get_static_pad(in_level, "sink");
-    auto pad_src = gst_element_get_static_pad(out_level, "src");
+    auto* pad_sink = gst_element_get_static_pad(in_level, "sink");
+    auto* pad_src = gst_element_get_static_pad(out_level, "src");
 
     gst_element_add_pad(bin, gst_ghost_pad_new("sink", pad_sink));
     gst_element_add_pad(bin, gst_ghost_pad_new("src", pad_src));
