@@ -1,5 +1,6 @@
 #include "multiband_gate.hpp"
 #include <glibmm/main.h>
+#include <array>
 #include "util.hpp"
 
 namespace {
@@ -170,19 +171,19 @@ void on_post_messages_changed(GSettings* settings, gchar* key, MultibandGate* l)
 
 }  // namespace
 
-MultibandGate::MultibandGate(const std::string& tag, const std::string& schema)
-    : PluginBase(tag, "multiband_gate", schema) {
+MultibandGate::MultibandGate(const std::string& tag, const std::string& schema, const std::string& schema_path)
+    : PluginBase(tag, "multiband_gate", schema, schema_path) {
   multiband_gate = gst_element_factory_make("calf-sourceforge-net-plugins-MultibandGate", nullptr);
 
   if (is_installed(multiband_gate)) {
-    auto audioconvert_in = gst_element_factory_make("audioconvert", "multiband_gate_audioconvert_in");
-    auto audioconvert_out = gst_element_factory_make("audioconvert", "multiband_gate_audioconvert_out");
+    auto* audioconvert_in = gst_element_factory_make("audioconvert", "multiband_gate_audioconvert_in");
+    auto* audioconvert_out = gst_element_factory_make("audioconvert", "multiband_gate_audioconvert_out");
 
     gst_bin_add_many(GST_BIN(bin), audioconvert_in, multiband_gate, audioconvert_out, nullptr);
     gst_element_link_many(audioconvert_in, multiband_gate, audioconvert_out, nullptr);
 
-    auto pad_sink = gst_element_get_static_pad(audioconvert_in, "sink");
-    auto pad_src = gst_element_get_static_pad(audioconvert_out, "src");
+    auto* pad_sink = gst_element_get_static_pad(audioconvert_in, "sink");
+    auto* pad_src = gst_element_get_static_pad(audioconvert_out, "src");
 
     gst_element_add_pad(bin, gst_ghost_pad_new("sink", pad_sink));
     gst_element_add_pad(bin, gst_ghost_pad_new("src", pad_src));
