@@ -1,11 +1,12 @@
 #include "plugin_ui_base.hpp"
 
-PluginUiBase::PluginUiBase(const Glib::RefPtr<Gtk::Builder>& builder, const std::string& settings_name)
-    : settings(Gio::Settings::create(settings_name)) {
+PluginUiBase::PluginUiBase(const Glib::RefPtr<Gtk::Builder>& builder,
+                           const std::string& schema,
+                           const std::string& schema_path)
+    : settings(Gio::Settings::create(schema, schema_path)) {
   builder->get_widget("enable", enable);
   builder->get_widget("listbox_control", listbox_control);
   builder->get_widget("controls", controls);
-  builder->get_widget("img_state", img_state);
   builder->get_widget("plugin_up", plugin_up);
   builder->get_widget("plugin_down", plugin_down);
 
@@ -29,13 +30,12 @@ PluginUiBase::PluginUiBase(const Glib::RefPtr<Gtk::Builder>& builder, const std:
 
   settings->bind("state", enable, "active", flag);
   settings->bind("state", controls, "sensitive", flag_get);
-  settings->bind("state", img_state, "visible", flag_get);
 
   settings->set_boolean("post-messages", settings->get_boolean("state"));
 }
 
 PluginUiBase::~PluginUiBase() {
-  for (auto c : connections) {
+  for (auto& c : connections) {
     c.disconnect();
   }
 
@@ -53,18 +53,6 @@ auto PluginUiBase::level_to_str(const double& value, const int& places) -> std::
 
 void PluginUiBase::on_new_input_level(const std::array<double, 2>& peak) {
   update_level(input_level_left, input_level_left_label, input_level_right, input_level_right_label, peak);
-
-  if (peak[0] > 1 || peak[1] > 1) {
-    input_saturated = true;
-
-    img_state->set_from_icon_name("dialog-warning-symbolic", Gtk::ICON_SIZE_BUTTON);
-  } else if (peak[0] <= 1 && peak[1] <= 1) {
-    if (input_saturated) {
-      img_state->set_from_icon_name("emblem-ok-symbolic", Gtk::ICON_SIZE_BUTTON);
-    }
-
-    input_saturated = false;
-  }
 }
 
 void PluginUiBase::on_new_output_level(const std::array<double, 2>& peak) {
@@ -73,18 +61,6 @@ void PluginUiBase::on_new_output_level(const std::array<double, 2>& peak) {
 
 void PluginUiBase::on_new_input_level_db(const std::array<double, 2>& peak) {
   update_level_db(input_level_left, input_level_left_label, input_level_right, input_level_right_label, peak);
-
-  if (peak[0] > 0 || peak[1] > 0) {
-    input_saturated = true;
-
-    img_state->set_from_icon_name("dialog-warning-symbolic", Gtk::ICON_SIZE_BUTTON);
-  } else if (peak[0] <= 0 && peak[1] <= 0) {
-    if (input_saturated) {
-      img_state->set_from_icon_name("emblem-ok-symbolic", Gtk::ICON_SIZE_BUTTON);
-    }
-
-    input_saturated = false;
-  }
 }
 
 void PluginUiBase::on_new_output_level_db(const std::array<double, 2>& peak) {
