@@ -1,6 +1,8 @@
 #include "presets_menu_ui.hpp"
 #include <glibmm/i18n.h>
 #include <gtkmm/applicationwindow.h>
+#include <gtkmm/dialog.h>
+#include <gtkmm/filechoosernative.h>
 #include <gtkmm/togglebutton.h>
 #include "util.hpp"
 
@@ -40,7 +42,7 @@ PresetsMenuUi::PresetsMenuUi(BaseObjectType* cobject,
 }
 
 PresetsMenuUi::~PresetsMenuUi() {
-  for (auto c : connections) {
+  for (auto& c : connections) {
     c.disconnect();
   }
 
@@ -52,7 +54,7 @@ auto PresetsMenuUi::add_to_popover(Gtk::Popover* popover, Application* app) -> P
 
   auto settings = Gio::Settings::create("com.github.wwmm.pulseeffects");
 
-  PresetsMenuUi* ui;
+  PresetsMenuUi* ui = nullptr;
 
   builder->get_widget_derived("widgets_grid", ui, settings, app);
 
@@ -101,60 +103,37 @@ void PresetsMenuUi::create_preset(PresetType preset_type) {
 }
 
 void PresetsMenuUi::import_preset(PresetType preset_type) {
-  // gtkmm 3.22 does not have FileChooseNative so we have to use C api :-(
+  auto* main_window = dynamic_cast<Gtk::Window*>(this->get_toplevel());
 
-  gint res;
+  auto dialog = Gtk::FileChooserNative::create(
+      _("Import Presets"), *main_window, Gtk::FileChooserAction::FILE_CHOOSER_ACTION_OPEN, _("Open"), _("Cancel"));
 
-  auto main_window = gtk_widget_get_toplevel((GtkWidget*)this->gobj());
+  auto dialog_filter = Gtk::FileFilter::create();
 
-  auto dialog = gtk_file_chooser_native_new(_("Import Presets"), (GtkWindow*)main_window, GTK_FILE_CHOOSER_ACTION_OPEN,
-                                            _("Open"), _("Cancel"));
+  dialog_filter->set_name(_("Presets"));
+  dialog_filter->add_pattern("*.json");
 
-  auto filter = gtk_file_filter_new();
+  dialog->add_filter(dialog_filter);
 
-  gtk_file_filter_set_name(filter, _("Presets"));
-  gtk_file_filter_add_pattern(filter, "*.json");
-  gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(dialog), filter);
+  dialog->signal_response().connect([=](auto response_id) {
+    switch (response_id) {
+      case Gtk::ResponseType::RESPONSE_ACCEPT: {
+        for (const auto& file_path : dialog->get_filenames()) {
+          app->presets_manager->import(preset_type, file_path);
+        }
 
-  res = gtk_native_dialog_run(GTK_NATIVE_DIALOG(dialog));
+        populate_listbox(preset_type);
 
-  if (res == GTK_RESPONSE_ACCEPT) {
-    GtkFileChooser* chooser = GTK_FILE_CHOOSER(dialog);
-
-    auto file_list = gtk_file_chooser_get_filenames(chooser);
-
-    if (preset_type == PresetType::input) {
-      g_slist_foreach(
-          file_list,
-          [](auto data, auto user_data) {
-            auto aui = static_cast<PresetsMenuUi*>(user_data);
-
-            auto file_path = static_cast<char*>(data);
-
-            aui->app->presets_manager->import(PresetType::input, file_path);
-          },
-          this);
+        break;
+      }
+      default:
+        break;
     }
+  });
 
-    if (preset_type == PresetType::output) {
-      g_slist_foreach(
-          file_list,
-          [](auto data, auto user_data) {
-            auto aui = static_cast<PresetsMenuUi*>(user_data);
-
-            auto file_path = static_cast<char*>(data);
-
-            aui->app->presets_manager->import(PresetType::output, file_path);
-          },
-          this);
-    }
-
-    g_slist_free(file_list);
-  }
-
-  g_object_unref(dialog);
-
-  populate_listbox(preset_type);
+  dialog->set_modal(true);
+  dialog->set_select_multiple(true);
+  dialog->show();
 }
 
 auto PresetsMenuUi::on_listbox_sort(Gtk::ListBoxRow* row1, Gtk::ListBoxRow* row2) -> int {
@@ -188,7 +167,7 @@ void PresetsMenuUi::on_presets_menu_button_clicked() {
 }
 
 void PresetsMenuUi::populate_listbox(PresetType preset_type) {
-  Gtk::ListBox* listbox;
+  Gtk::ListBox* listbox = nullptr;
 
   if (preset_type == PresetType::output) {
     listbox = output_listbox;
@@ -207,12 +186,12 @@ void PresetsMenuUi::populate_listbox(PresetType preset_type) {
   for (const auto& name : names) {
     auto b = Gtk::Builder::create_from_resource("/com/github/wwmm/pulseeffects/ui/preset_row.glade");
 
-    Gtk::ListBoxRow* row;
-    Gtk::Button* apply_btn;
-    Gtk::Button* save_btn;
-    Gtk::Button* remove_btn;
-    Gtk::Label* label;
-    Gtk::ToggleButton* autoload_btn;
+    Gtk::ListBoxRow* row = nullptr;
+    Gtk::Button* apply_btn = nullptr;
+    Gtk::Button* save_btn = nullptr;
+    Gtk::Button* remove_btn = nullptr;
+    Gtk::Label* label = nullptr;
+    Gtk::ToggleButton* autoload_btn = nullptr;
 
     b->get_widget("preset_row", row);
     b->get_widget("apply", apply_btn);
@@ -235,7 +214,8 @@ void PresetsMenuUi::populate_listbox(PresetType preset_type) {
       app->presets_manager->load(preset_type, row->get_name());
     }));
 
-    connections.emplace_back(save_btn->signal_clicked().connect([=]() { app->presets_manager->save(preset_type, name); }));
+    connections.emplace_back(
+        save_btn->signal_clicked().connect([=]() { app->presets_manager->save(preset_type, name); }));
 
     connections.emplace_back(autoload_btn->signal_toggled().connect([=]() {
       if (preset_type == PresetType::output) {
