@@ -1,5 +1,6 @@
 #include "reverb.hpp"
 #include <glibmm/main.h>
+#include <array>
 #include "util.hpp"
 
 namespace {
@@ -51,19 +52,20 @@ void on_post_messages_changed(GSettings* settings, gchar* key, Reverb* l) {
 
 }  // namespace
 
-Reverb::Reverb(const std::string& tag, const std::string& schema) : PluginBase(tag, "reverb", schema) {
+Reverb::Reverb(const std::string& tag, const std::string& schema, const std::string& schema_path)
+    : PluginBase(tag, "reverb", schema, schema_path) {
   reverb = gst_element_factory_make("calf-sourceforge-net-plugins-Reverb", "reverb");
 
   if (is_installed(reverb)) {
-    auto audioconvert_in = gst_element_factory_make("audioconvert", "reverb_audioconvert_in");
-    auto audioconvert_out = gst_element_factory_make("audioconvert", "reverb_audioconvert_out");
+    auto* audioconvert_in = gst_element_factory_make("audioconvert", "reverb_audioconvert_in");
+    auto* audioconvert_out = gst_element_factory_make("audioconvert", "reverb_audioconvert_out");
 
     gst_bin_add_many(GST_BIN(bin), audioconvert_in, reverb, audioconvert_out, nullptr);
 
     gst_element_link_many(audioconvert_in, reverb, audioconvert_out, nullptr);
 
-    auto pad_sink = gst_element_get_static_pad(audioconvert_in, "sink");
-    auto pad_src = gst_element_get_static_pad(audioconvert_out, "src");
+    auto* pad_sink = gst_element_get_static_pad(audioconvert_in, "sink");
+    auto* pad_src = gst_element_get_static_pad(audioconvert_out, "src");
 
     gst_element_add_pad(bin, gst_ghost_pad_new("sink", pad_sink));
     gst_element_add_pad(bin, gst_ghost_pad_new("src", pad_src));
