@@ -1,6 +1,5 @@
 #include "reverb_ui.hpp"
 #include <cstring>
-#include "util.hpp"
 
 namespace {
 
@@ -52,8 +51,11 @@ auto int_to_room_size_enum(const GValue* value, const GVariantType* expected_typ
 
 }  // namespace
 
-ReverbUi::ReverbUi(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder, const std::string& settings_name)
-    : Gtk::Grid(cobject), PluginUiBase(builder, settings_name) {
+ReverbUi::ReverbUi(BaseObjectType* cobject,
+                   const Glib::RefPtr<Gtk::Builder>& builder,
+                   const std::string& schema,
+                   const std::string& schema_path)
+    : Gtk::Grid(cobject), PluginUiBase(builder, schema, schema_path) {
   name = "reverb";
 
   // loading glade widgets
