@@ -1,4 +1,5 @@
 #include "source_output_effects_ui.hpp"
+#include "preset_type.hpp"
 
 SourceOutputEffectsUi::SourceOutputEffectsUi(BaseObjectType* cobject,
                                              const Glib::RefPtr<Gtk::Builder>& refBuilder,
@@ -19,23 +20,51 @@ SourceOutputEffectsUi::SourceOutputEffectsUi(BaseObjectType* cobject,
   auto b_multiband_compressor =
       Gtk::Builder::create_from_resource("/com/github/wwmm/pulseeffects/ui/multiband_compressor.glade");
   auto b_multiband_gate = Gtk::Builder::create_from_resource("/com/github/wwmm/pulseeffects/ui/multiband_gate.glade");
+  auto b_stereo_tools = Gtk::Builder::create_from_resource("/com/github/wwmm/pulseeffects/ui/stereo_tools.glade");
+  auto b_maximizer = Gtk::Builder::create_from_resource("/com/github/wwmm/pulseeffects/ui/maximizer.glade");
+
+  b_limiter->get_widget_derived("widgets_grid", limiter_ui, "com.github.wwmm.pulseeffects.limiter",
+                                "/com/github/wwmm/pulseeffects/sourceoutputs/limiter/");
+
+  b_compressor->get_widget_derived("widgets_grid", compressor_ui, "com.github.wwmm.pulseeffects.compressor",
+                                   "/com/github/wwmm/pulseeffects/sourceoutputs/compressor/");
+
+  b_filter->get_widget_derived("widgets_grid", filter_ui, "com.github.wwmm.pulseeffects.filter",
+                               "/com/github/wwmm/pulseeffects/sourceoutputs/filter/");
+
+  b_equalizer->get_widget_derived("widgets_grid", equalizer_ui, "com.github.wwmm.pulseeffects.equalizer",
+                                  "/com/github/wwmm/pulseeffects/sourceoutputs/equalizer/",
+                                  "com.github.wwmm.pulseeffects.equalizer.channel",
+                                  "/com/github/wwmm/pulseeffects/sourceoutputs/equalizer/leftchannel/",
+                                  "/com/github/wwmm/pulseeffects/sourceoutputs/equalizer/rightchannel/");
+
+  b_reverb->get_widget_derived("widgets_grid", reverb_ui, "com.github.wwmm.pulseeffects.reverb",
+                               "/com/github/wwmm/pulseeffects/sourceoutputs/reverb/");
+
+  b_gate->get_widget_derived("widgets_grid", gate_ui, "com.github.wwmm.pulseeffects.gate",
+                             "/com/github/wwmm/pulseeffects/sourceoutputs/gate/");
+
+  b_deesser->get_widget_derived("widgets_grid", deesser_ui, "com.github.wwmm.pulseeffects.deesser",
+                                "/com/github/wwmm/pulseeffects/sourceoutputs/deesser/");
+
+  b_pitch->get_widget_derived("widgets_grid", pitch_ui, "com.github.wwmm.pulseeffects.pitch",
+                              "/com/github/wwmm/pulseeffects/sourceoutputs/pitch/");
+
+  b_webrtc->get_widget_derived("widgets_grid", webrtc_ui, "com.github.wwmm.pulseeffects.webrtc",
+                               "/com/github/wwmm/pulseeffects/sourceoutputs/webrtc/");
 
-  b_limiter->get_widget_derived("widgets_grid", limiter_ui, "com.github.wwmm.pulseeffects.sourceoutputs.limiter");
-  b_compressor->get_widget_derived("widgets_grid", compressor_ui,
-                                   "com.github.wwmm.pulseeffects.sourceoutputs.compressor");
-  b_filter->get_widget_derived("widgets_grid", filter_ui, "com.github.wwmm.pulseeffects.sourceoutputs.filter");
-  b_equalizer->get_widget_derived("widgets_grid", equalizer_ui, "com.github.wwmm.pulseeffects.sourceoutputs.equalizer",
-                                  "com.github.wwmm.pulseeffects.sourceoutputs.equalizer.leftchannel",
-                                  "com.github.wwmm.pulseeffects.sourceoutputs.equalizer.rightchannel");
-  b_reverb->get_widget_derived("widgets_grid", reverb_ui, "com.github.wwmm.pulseeffects.sourceoutputs.reverb");
-  b_gate->get_widget_derived("widgets_grid", gate_ui, "com.github.wwmm.pulseeffects.sourceoutputs.gate");
-  b_deesser->get_widget_derived("widgets_grid", deesser_ui, "com.github.wwmm.pulseeffects.sourceoutputs.deesser");
-  b_pitch->get_widget_derived("widgets_grid", pitch_ui, "com.github.wwmm.pulseeffects.sourceoutputs.pitch");
-  b_webrtc->get_widget_derived("widgets_grid", webrtc_ui, "com.github.wwmm.pulseeffects.sourceoutputs.webrtc");
   b_multiband_compressor->get_widget_derived("widgets_grid", multiband_compressor_ui,
-                                             "com.github.wwmm.pulseeffects.sourceoutputs.multibandcompressor");
-  b_multiband_gate->get_widget_derived("widgets_grid", multiband_gate_ui,
-                                       "com.github.wwmm.pulseeffects.sourceoutputs.multibandgate");
+                                             "com.github.wwmm.pulseeffects.multibandcompressor",
+                                             "/com/github/wwmm/pulseeffects/sourceoutputs/multibandcompressor/");
+
+  b_multiband_gate->get_widget_derived("widgets_grid", multiband_gate_ui, "com.github.wwmm.pulseeffects.multibandgate",
+                                       "/com/github/wwmm/pulseeffects/sourceoutputs/multibandgate/");
+
+  b_stereo_tools->get_widget_derived("widgets_grid", stereo_tools_ui, "com.github.wwmm.pulseeffects.stereotools",
+                                     "/com/github/wwmm/pulseeffects/sourceoutputs/stereotools/");
+
+  b_maximizer->get_widget_derived("widgets_grid", maximizer_ui, "com.github.wwmm.pulseeffects.maximizer",
+                                  "/com/github/wwmm/pulseeffects/sourceoutputs/maximizer/");
 
   // set preset type property inside user interfaces to be intepreted as "input"
 
@@ -50,6 +79,8 @@ SourceOutputEffectsUi::SourceOutputEffectsUi(BaseObjectType* cobject,
   webrtc_ui->preset_type = PresetType::input;
   multiband_compressor_ui->preset_type = PresetType::input;
   multiband_gate_ui->preset_type = PresetType::input;
+  stereo_tools_ui->preset_type = PresetType::input;
+  maximizer_ui->preset_type = PresetType::input;
 
   // add to stack
 
@@ -64,6 +95,8 @@ SourceOutputEffectsUi::SourceOutputEffectsUi(BaseObjectType* cobject,
   stack->add(*webrtc_ui, webrtc_ui->name);
   stack->add(*multiband_compressor_ui, multiband_compressor_ui->name);
   stack->add(*multiband_gate_ui, multiband_gate_ui->name);
+  stack->add(*stereo_tools_ui, stereo_tools_ui->name);
+  stack->add(*maximizer_ui, maximizer_ui->name);
 
   // populate listbox
 
@@ -78,6 +111,8 @@ SourceOutputEffectsUi::SourceOutputEffectsUi(BaseObjectType* cobject,
   add_to_listbox(webrtc_ui);
   add_to_listbox(multiband_compressor_ui);
   add_to_listbox(multiband_gate_ui);
+  add_to_listbox(stereo_tools_ui);
+  add_to_listbox(maximizer_ui);
 
   level_meters_connections();
   up_down_connections();
@@ -102,7 +137,7 @@ auto SourceOutputEffectsUi::add_to_stack(Gtk::Stack* stack, SourceOutputEffects*
 
   auto settings = Gio::Settings::create("com.github.wwmm.pulseeffects.sourceoutputs");
 
-  SourceOutputEffectsUi* ui;
+  SourceOutputEffectsUi* ui = nullptr;
 
   builder->get_widget_derived("widgets_box", ui, settings, soe_ptr);
 
@@ -146,6 +181,11 @@ void SourceOutputEffectsUi::on_app_added(std::shared_ptr<AppInfo> app_info) {
 }
 
 void SourceOutputEffectsUi::level_meters_connections() {
+  // global output level meter connection
+
+  connections.emplace_back(
+      soe->global_output_level.connect(sigc::mem_fun(this, &SourceOutputEffectsUi::on_new_output_level_db)));
+
   // limiter level meters connections
 
   connections.emplace_back(
@@ -263,6 +303,22 @@ void SourceOutputEffectsUi::level_meters_connections() {
       soe->multiband_gate->gating2.connect(sigc::mem_fun(*multiband_gate_ui, &MultibandGateUi::on_new_gating2)));
   connections.emplace_back(
       soe->multiband_gate->gating3.connect(sigc::mem_fun(*multiband_gate_ui, &MultibandGateUi::on_new_gating3)));
+
+  // stereo_tools level meters connections
+
+  connections.emplace_back(
+      soe->stereo_tools->input_level.connect(sigc::mem_fun(*stereo_tools_ui, &StereoToolsUi::on_new_input_level)));
+  connections.emplace_back(
+      soe->stereo_tools->output_level.connect(sigc::mem_fun(*stereo_tools_ui, &StereoToolsUi::on_new_output_level)));
+
+  // maximizer level meters connections
+
+  connections.emplace_back(
+      soe->maximizer_input_level.connect(sigc::mem_fun(*maximizer_ui, &MaximizerUi::on_new_input_level_db)));
+  connections.emplace_back(
+      soe->maximizer_output_level.connect(sigc::mem_fun(*maximizer_ui, &MaximizerUi::on_new_output_level_db)));
+  connections.emplace_back(
+      soe->maximizer->reduction.connect(sigc::mem_fun(*maximizer_ui, &MaximizerUi::on_new_reduction)));
 }
 
 void SourceOutputEffectsUi::up_down_connections() {
@@ -333,4 +389,10 @@ void SourceOutputEffectsUi::up_down_connections() {
   connections.emplace_back(multiband_gate_ui->plugin_up->signal_clicked().connect([=]() { on_up(multiband_gate_ui); }));
   connections.emplace_back(
       multiband_gate_ui->plugin_down->signal_clicked().connect([=]() { on_down(multiband_gate_ui); }));
+
+  connections.emplace_back(stereo_tools_ui->plugin_up->signal_clicked().connect([=]() { on_up(stereo_tools_ui); }));
+  connections.emplace_back(stereo_tools_ui->plugin_down->signal_clicked().connect([=]() { on_down(stereo_tools_ui); }));
+
+  connections.emplace_back(maximizer_ui->plugin_up->signal_clicked().connect([=]() { on_up(maximizer_ui); }));
+  connections.emplace_back(maximizer_ui->plugin_down->signal_clicked().connect([=]() { on_down(maximizer_ui); }));
 }
