@@ -5,7 +5,7 @@
 namespace {
 
 auto spectrum_type_enum_to_int(GValue* value, GVariant* variant, gpointer user_data) -> gboolean {
-  auto v = g_variant_get_string(variant, nullptr);
+  const auto* v = g_variant_get_string(variant, nullptr);
 
   if (std::strcmp(v, "Bars") == 0) {
     g_value_set_int(value, 0);
@@ -39,6 +39,7 @@ SpectrumSettingsUi::SpectrumSettingsUi(BaseObjectType* cobject,
   builder->get_widget("fill", fill);
   builder->get_widget("show_bar_border", show_bar_border);
   builder->get_widget("spectrum_color_button", spectrum_color_button);
+  builder->get_widget("axis_color_button", axis_color_button);
   builder->get_widget("gradient_color_button", gradient_color_button);
   builder->get_widget("use_custom_color", use_custom_color);
   builder->get_widget("use_gradient", use_gradient);
@@ -46,10 +47,10 @@ SpectrumSettingsUi::SpectrumSettingsUi(BaseObjectType* cobject,
 
   get_object(builder, "n_points", n_points);
   get_object(builder, "height", height);
-  get_object(builder, "scale", scale);
-  get_object(builder, "exponent", exponent);
   get_object(builder, "sampling_freq", sampling_freq);
   get_object(builder, "line_width", line_width);
+  get_object(builder, "maximum_frequency", maximum_frequency);
+  get_object(builder, "minimum_frequency", minimum_frequency);
 
   // signals connection
 
@@ -92,6 +93,15 @@ SpectrumSettingsUi::SpectrumSettingsUi(BaseObjectType* cobject,
     settings->set_value("color", v);
   });
 
+  axis_color_button->signal_color_set().connect([&]() {
+    auto axis_color = axis_color_button->get_rgba();
+
+    auto v = Glib::Variant<std::vector<double>>::create(std::vector<double>{
+        axis_color.get_red(), axis_color.get_green(), axis_color.get_blue(), axis_color.get_alpha()});
+
+    settings->set_value("color-axis-labels", v);
+  });
+
   gradient_color_button->signal_color_set().connect([&]() {
     auto color = gradient_color_button->get_rgba();
 
@@ -106,6 +116,26 @@ SpectrumSettingsUi::SpectrumSettingsUi(BaseObjectType* cobject,
   sampling_freq->signal_value_changed().connect(
       sigc::mem_fun(*this, &SpectrumSettingsUi::on_spectrum_sampling_freq_set), false);
 
+  minimum_frequency->signal_value_changed().connect([&]() {
+    if (minimum_frequency->get_value() < maximum_frequency->get_value()) {
+      app->sie->min_spectrum_freq = minimum_frequency->get_value();
+      app->soe->min_spectrum_freq = minimum_frequency->get_value();
+
+      app->sie->init_spectrum();
+      app->soe->init_spectrum();
+    }
+  });
+
+  maximum_frequency->signal_value_changed().connect([&]() {
+    if (maximum_frequency->get_value() > minimum_frequency->get_value()) {
+      app->sie->max_spectrum_freq = maximum_frequency->get_value();
+      app->soe->max_spectrum_freq = maximum_frequency->get_value();
+
+      app->sie->init_spectrum();
+      app->soe->init_spectrum();
+    }
+  });
+
   auto flag = Gio::SettingsBindFlags::SETTINGS_BIND_DEFAULT;
 
   settings->bind("show", show, "active", flag);
@@ -114,21 +144,22 @@ SpectrumSettingsUi::SpectrumSettingsUi(BaseObjectType* cobject,
   settings->bind("show-bar-border", show_bar_border, "active", flag);
   settings->bind("n-points", n_points.get(), "value", flag);
   settings->bind("height", height.get(), "value", flag);
-  settings->bind("scale", scale.get(), "value", flag);
-  settings->bind("exponent", exponent.get(), "value", flag);
   settings->bind("sampling-freq", sampling_freq.get(), "value", flag);
   settings->bind("line-width", line_width.get(), "value", flag);
   settings->bind("use-gradient", use_gradient, "active", flag);
   settings->bind("use-custom-color", use_custom_color, "active", flag);
   settings->bind("use-custom-color", spectrum_color_button, "sensitive", flag);
   settings->bind("use-custom-color", gradient_color_button, "sensitive", flag);
+  settings->bind("use-custom-color", axis_color_button, "sensitive", flag);
+  settings->bind("minimum-frequency", minimum_frequency.get(), "value", flag);
+  settings->bind("maximum-frequency", maximum_frequency.get(), "value", flag);
 
   g_settings_bind_with_mapping(settings->gobj(), "type", spectrum_type->gobj(), "active", G_SETTINGS_BIND_DEFAULT,
                                spectrum_type_enum_to_int, int_to_spectrum_type_enum, nullptr, nullptr);
 }
 
 SpectrumSettingsUi::~SpectrumSettingsUi() {
-  for (auto c : connections) {
+  for (auto& c : connections) {
     c.disconnect();
   }
 
@@ -138,7 +169,7 @@ SpectrumSettingsUi::~SpectrumSettingsUi() {
 void SpectrumSettingsUi::add_to_stack(Gtk::Stack* stack, Application* app) {
   auto builder = Gtk::Builder::create_from_resource("/com/github/wwmm/pulseeffects/ui/spectrum_settings.glade");
 
-  SpectrumSettingsUi* ui;
+  SpectrumSettingsUi* ui = nullptr;
 
   builder->get_widget_derived("widgets_grid", ui, app);
 
